
|Python27|_ |Python35|_ | |PyPi|_

.. |Python27| image:: https://img.shields.io/badge/python-2.7-blue.svg
.. _Python27: https://badge.fury.io/py/pycaravel

.. |Python35| image:: https://img.shields.io/badge/python-3.5-blue.svg
.. _Python35: https://badge.fury.io/py/pycaravel

.. |PyPi| image:: https://badge.fury.io/py/pycaravel.svg
.. _PyPi: https://badge.fury.io/py/pycaravel


pycaravel
=========

This module has been created to simplify the search of datasets in a BIDS
directory or a CubicWeb instance.


Important links
===============

- Official source code repo: https://github.com/neurospin/pycaravel
- HTML documentation (last stable release): http://neurospin.github.io/pycaravel


Dependencies
============

The required dependencies to use the software are:

* pandas
* grabbit


Install
=======

Check the official documentation dedicated page.
